aboutsummaryrefslogtreecommitdiffstats
path: root/calendar/gui/e-cal-popup.h
diff options
context:
space:
mode:
authorNot Zed <NotZed@Ximian.com>2004-10-18 12:08:47 +0800
committerMichael Zucci <zucchi@src.gnome.org>2004-10-18 12:08:47 +0800
commit48988a8a72a5869621e628a03011879508a8432b (patch)
treeadbf33e097109cf2a008d6892dd4859dcda196e9 /calendar/gui/e-cal-popup.h
parent835302d0021f020cb9776a417b3e5e49a676e4c2 (diff)
downloadgsoc2013-evolution-48988a8a72a5869621e628a03011879508a8432b.tar
gsoc2013-evolution-48988a8a72a5869621e628a03011879508a8432b.tar.gz
gsoc2013-evolution-48988a8a72a5869621e628a03011879508a8432b.tar.bz2
gsoc2013-evolution-48988a8a72a5869621e628a03011879508a8432b.tar.lz
gsoc2013-evolution-48988a8a72a5869621e628a03011879508a8432b.tar.xz
gsoc2013-evolution-48988a8a72a5869621e628a03011879508a8432b.tar.zst
gsoc2013-evolution-48988a8a72a5869621e628a03011879508a8432b.zip
dont access a NULL client.
2004-10-14 Not Zed <NotZed@Ximian.com> * gui/e-cal-menu.c (e_cal_menu_target_new_select): dont access a NULL client. * gui/gnome-cal.c (gnome_calendar_get_taskpad_menu) (gnome_calendar_get_calendar_menu): accessors to get the menu managers. (gnome_calendar_init): setup menu managers. 2004-10-13 Not Zed <NotZed@Ximian.com> * gui/calendar-commands.c (calendar_control_activate) (calendar_control_deactivate): activate and deactivate the calendar and taskpad menu handlers. (sensitize_items): helper to sensitise items based on target masks. (calendar_control_sensitize_calendar_commands): update the calendar menu manager target appropriately. (sensitize_taskpad_commands): same for the taskpad. * gui/e-cal-menu.[ch]: Targets for main menu management. * gui/e-cal-popup.c (e_cal_popup_target_new_select): fix cast. Also include the tasks stuff in the hook metadata. svn path=/trunk/; revision=27607
Diffstat (limited to 'calendar/gui/e-cal-popup.h')
-rw-r--r--calendar/gui/e-cal-popup.h29
1 files changed, 16 insertions, 13 deletions
diff --git a/calendar/gui/e-cal-popup.h b/calendar/gui/e-cal-popup.h
index d9aeb83342..1e7d7bc23a 100644
--- a/calendar/gui/e-cal-popup.h
+++ b/calendar/gui/e-cal-popup.h
@@ -53,7 +53,8 @@ enum _e_cal_popup_target_t {
* enum _e_cal_popup_target_select_t - ECalPopupTargetSelect qualifiers.
*
* @E_CAL_POPUP_SELECT_ONE: Only one item is selected.
* @E_CAL_POPUP_SELECT_MANY: One ore more items are selected.
* @E_CAL_POPUP_SELECT_EDITABLE: The selection is editable.
* @E_CAL_POPUP_SELECT_RECURRING: Is a recurring event.
* @E_CAL_POPUP_SELECT_NONRECURRING: Is not a recurring event.
@@ -61,22 +62,24 @@ enum _e_cal_popup_target_t {
* @E_CAL_POPUP_SELECT_ORGANIZER: The user is the organiser of the event.
* @E_CAL_POPUP_SELECT_NOTEDITING: The event is not being edited already. Not implemented.
* @E_CAL_POPUP_SELECT_NOTMEETING: The event is not a meeting.
- *
+ * @E_CAL_POPUP_SELECT_ASSIGNABLE: An assignable task.
+ * @E_CAL_POPUP_SELECT_HASURL: A task that contains a URL.
**/
enum _e_cal_popup_target_select_t {
E_CAL_POPUP_SELECT_ONE = 1<<0,
E_CAL_POPUP_SELECT_MANY = 1<<1,
- E_CAL_POPUP_SELECT_EDITABLE = 1<<2,
- E_CAL_POPUP_SELECT_RECURRING = 1<<3,
- E_CAL_POPUP_SELECT_NONRECURRING = 1<<4,
- E_CAL_POPUP_SELECT_INSTANCE = 1<<5,
-
- E_CAL_POPUP_SELECT_ORGANIZER = 1<<6,
- E_CAL_POPUP_SELECT_NOTEDITING = 1<<7,
- E_CAL_POPUP_SELECT_NOTMEETING = 1<<8,
-
- E_CAL_POPUP_SELECT_ASSIGNABLE = 1<<9,
- E_CAL_POPUP_SELECT_HASURL = 1<<10,
+ E_CAL_POPUP_SELECT_ANY = 1<<2,
+ E_CAL_POPUP_SELECT_EDITABLE = 1<<3,
+ E_CAL_POPUP_SELECT_RECURRING = 1<<4,
+ E_CAL_POPUP_SELECT_NONRECURRING = 1<<5,
+ E_CAL_POPUP_SELECT_INSTANCE = 1<<6,
+
+ E_CAL_POPUP_SELECT_ORGANIZER = 1<<7,
+ E_CAL_POPUP_SELECT_NOTEDITING = 1<<8,
+ E_CAL_POPUP_SELECT_NOTMEETING = 1<<9,
+
+ E_CAL_POPUP_SELECT_ASSIGNABLE = 1<<10,
+ E_CAL_POPUP_SELECT_HASURL = 1<<11,
};
/**
@@ -53,7 +53,8 @@ enum _e_cal_popup_target_t {
*
* @E_CAL_POPUP_SELECT_ONE: Only one item is selected.
- * @E_CAL_POPUP_SELECT_MANY: One ore more items are selected.
+ * @E_CAL_POPUP_SELECT_MANY: More than one item selected.
+ * @E_CAL_POPUP_SELECT_ANY: One ore more items are selected.
* @E_CAL_POPUP_SELECT_EDITABLE: The selection is editable.
* @E_CAL_POPUP_SELECT_RECURRING: Is a recurring event.